@@ -1,4 +1,4 @@
-from opengl_classes import *
+from .opengl_classes import *
 import glfw
 import math
 import matplotlib.pyplot as plt
